const app = getApp()

import Dialog from '@vant/weapp/dialog/dialog';
import Notify from '@vant/weapp/notify/notify';

import {
  selfFormatTimeYMD,
  selfFormatTimeHM,
  twoTimeIntervalReturnHours
} from "../../../../../utils/util.js"

import {
  selectReservationByIdRq,
  cancelOrderRq,
  inviteRecordPersonListRq,
  getMeetingRoomServiceAndEquipmentRq,
} from "../../../../../api/meeting/meetingRoom.js"

Page({

  /**
   * 页面的初始数据
   */
  data: {
    IMG_NAME: app.IMG_NAME,
    id: null,
    detail: null,
    facilities: {},
    joinPersonList: [],
    showCancelReason: false, // 是否展示弹出层
    cancelId: '', // 取消预约会议id
    cancelReason: '', // 取消预约原因
    beforeClose(action) {
      return new Promise(resolve => {
        if (action === 'confirm') {
          resolve(false)
        } else {
          resolve(true)
        }
      });
    }, // 弹出层点击确认不关闭，手动关
    // 会议重新预约需要参数
    showEdit: false,
    editAction: [
      {
        name: '重新选择时间、会议室',
        type: 1
      },
      {
        name: '重新编辑会议信息',
        type: 2
      },
    ],
    timeShow: false,
    currentDate: new Date().getTime(),
    minDate: new Date().getTime(),
    maxDate: '',
    formatter(type, value) {
      if (type === 'year') {
        return `${value}年`;
      }
      if (type === 'month') {
        return `${value}月`;
      }
      if (type === 'day') {
        return `${value}日`;
      }
      return value;
    },
    // 驳回相关参数
    showRejectReason: false, // 是否展示弹出层
    rejectlId: '', // 驳回预约会议id
    rejectReason: '', // 驳回预约原因
    beforeReject(action) {
      return new Promise(resolve => {
        if (action === 'confirm') {
          resolve(false)
        } else {
          resolve(true)
        }
      });
    }, // 弹出层点击确认不关闭，手动关
    act: '' // 动作
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {
    let _this = this;
    _this.setData({
      ...options
    })
    // 获取详情
    _this.getDetail();
    // 获取一月后时间，默认只能选一个月之后
    const today = new Date()
    const newDate = new Date(today)
    newDate.setMonth(newDate.getMonth() + 1)
    _this.setData({
      maxDate: newDate.getTime()
    })
  },

  // 获取详情
  getDetail() {
    let _this = this;
    let id = _this.data.id;
    selectReservationByIdRq(id).then(res => {
      let detail = res.data;
      // 时间段
      detail.timeSlot = selfFormatTimeYMD(detail.startTime) + ' ' + selfFormatTimeHM(detail.startTime) + '~' + selfFormatTimeHM(detail.endDate);
      // 合计时间
      detail.countTime = twoTimeIntervalReturnHours(detail.startTime, detail.endDate)
      // 状态字体颜色
      let statusColor = "#FFB119";
      // 按钮是否显示
      let statusValue = detail.statusValue;
      let showPay = false;
      let showInvite = false;
      let showCancel = false;
      let showDetail = false;
      // 待支付 0 ：去支付、取消订单、查看详情
      if (statusValue == 0) {
        showPay = true;
        showCancel = true;
        showDetail = true;
        // 状态字体颜色
        statusColor = "#FFB119";
      }
      // 待使用 1：去邀请、取消订单、查看详情
      if (statusValue == 1) {
        showInvite = true;
        showCancel = true;
        showDetail = true;
        // 状态字体颜色
        statusColor = "#3794FF";
        // 待使用 修改为 预约成功
        detail.statusName = '预约成功'
      }
      // 进行中 2：去邀请、查看详情
      if (statusValue == 2) {
        showInvite = true;
        showDetail = true;
        // 状态字体颜色
        statusColor = "#FF4040";
      }
      // 已结束 3：查看详情
      if (statusValue == 3) {
        showDetail = true;
        // 状态字体颜色
        statusColor = "#333333";
      }
      // 已取消 4：查看详情
      if (statusValue == 4) {
        showDetail = true;
        // 状态字体颜色
        statusColor = "#7F7F7F";
      }
      //
      // 赋值
      detail.showPay = showPay;
      detail.showInvite = showInvite;
      detail.showCancel = showCancel;
      detail.showDetail = showDetail;
      // 状态字体颜色
      detail.statusColor = statusColor;
      // 图片
      if (detail.roomContent.indoorPicUrl) {
        try {
          detail.roomContent.indoorPicUrlFirst = JSON.parse(detail.roomContent.indoorPicUrl)[0].url
        } catch (error) {
          console.log(`JSON error : ${error}`);
        }
      }
      _this.setData({
        detail
      })

      // 查询服务
      getMeetingRoomServiceAndEquipmentRq(_this.data.detail.roomContent.id).then(res => {
        _this.setData({
          facilities: res.data
        })
      })
    })
    // 查询参与会议预约人员列表
    _this.getInviteRecordPersonList()
  },

  // 查询参与会议预约人员列表
  getInviteRecordPersonList() {
    let _this = this;
    let id = _this.data.id;
    inviteRecordPersonListRq(id).then(res => {
      console.log('inviteRecordPersonListRq', res);
      _this.setData({
        joinPersonList: res.data
      })
    })
  },
  pass() {
    Dialog.confirm({
        title: '确认',
        message: '是否确认通过会议室申请？',
      })
      .then(() => {
        // on confirm
        console.log('已通过')
        // 重新加载数据
        this.getDataList()
      })
      .catch(() => {
        // on cancel
      });
  },
  // 驳回预约
  rejectConfirm(e) {
    console.log('rejectConfirm', e);
    let _this = this;
    let id = e.currentTarget.dataset.id
    _this.setData({
      rejectId: id,
      showRejectReason: true,
      rejectReason: ''
    })
  },
  onCloseReject(e) {
    let _this = this;
    _this.setData({
      rejectId: '',
      showRejectReason: false,
      rejectReason: ''
    })
  },
  onChangeRejectReason(e) {
    let _this = this;
    _this.setData({
      rejectReason: e.detail
    })
  },
  // 取消订单
  rejectOrder() {
    let _this = this;
    let id = _this.data.rejectId
    let reason = _this.data.rejectReason
    if (id === '') {
      return
    }
    if (reason === '') {
      Notify('请输入驳回原因！')
      return
    }
    // 执行驳回方法
    console.log('驳回，原因为' + reason)
    return
    cancelOrderRq({
      id: id,
      cancelResaon: reason
    }).then(res => {
      console.log('rejectOrder', res);
      if (res.code == 0) {
        // 刷新预约数据
        _this.setData({
          reservationPageNum: 1,
          reservationDataList: [],
          reservationIsDataAll: false,
          showRejcctReason: false
        })
        _this.getDataList()
      } else {
        // 危险通知
        Notify({
          type: 'danger',
          message: res.msg
        });
      }
    })
  },
  // 取消预约一系列方法
  cancelConfirm(e) {
    console.log('cancelConfirm', e);
    let _this = this;
    let id = e.currentTarget.dataset.id
    _this.setData({
      cancelId: id,
      showCancelReason: true,
      cancelReason: ''
    })
  },
  onCloseCancel(e) {
    let _this = this;
    _this.setData({
      cancelId: '',
      showCancelReason: false,
      cancelReason: ''
    })
  },
  onChangeCancelReason(e) {
    let _this = this;
    _this.setData({
      cancelReason: e.detail
    })
  },
  // 取消订单
  cancelOrder() {
    let _this = this;
    let id = _this.data.cancelId
    let reason = _this.data.cancelReason
    if (id === '') {
      return
    }
    if (reason === '') {
      Notify('请输入取消原因！')
      return
    }
    cancelOrderRq({
      id: id,
      cancelResaon: reason
    }).then(res => {
      console.log('cancelOrderRq', res);
      if (res.code == 0) {
        _this.setData({
          showCancelReason: false
        })
        // 刷新数据
        _this.getDetail();
        // 数据状态变更，向上个页面传递变更
        let pages = getCurrentPages(); //获取page
        let prevPage = pages[pages.length - 2]; //上一个页面（父页面）
        prevPage.setData({
          dataChange: true
        })
      } else {
        // 危险通知
        Notify({
          type: 'danger',
          message: res.msg
        });
      }
    })
  },
  editConfirm() {
    this.setData({
      showEdit: true
    })
  },
  hideEdit() {
    this.setData({
      showEdit: false
    })
  },
  editMode(e) {
    let _this = this
    if (e.detail.type === 1) {
      // 重选时间会议室
      this.setData({
        showEdit: false,
        timeShow: true
      })
    } else {
      // 直接跳转
      console.log('重新编辑会议基本信息！')
      this.setData({
        showEdit: false,
      })
      wx.navigateTo({
        url: "/pages/meeting/meetingRoom/meetingOrder/meetingOrder?rId=" + _this.data.detail.id,
      })
    }
  },
  showTimePicker() {
    this.setData({
      timeShow: true
    });
  },
  hideTimePicker() {
    this.setData({
      timeShow: false
    });
  },
  // 跳转会议预约页面
  goRes(e) {
    let _this = this
    // 加入rId参数，为预约id，用于重新修改
    wx.navigateTo({
      url: '/pages/meeting/meetingReservation/meetingReservation?rId=' + _this.data.detail.id + '&time=' + e.detail,
    })
  },

  // 跳转-支付
  jumpPay(e) {
    console.log('jumpPay', e);
    wx.navigateTo({
      url: "/pages/meeting/pay/waitPay/waitPay?id=" + e.currentTarget.dataset.id + "&type=meetingRoom"
    })
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady() {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow() {

  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide() {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload() {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh() {

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom() {

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage(e) {
    console.log('onShareAppMessage', e);
    let _this = this;
    let id = e.target.dataset.id;
    let detail = _this.data.detail
    //
    let param = {
      title: detail.title,
      path: "/pages/meeting/invite/invite?id=" + id,
      imageUrl: app.IMG_NAME + detail.roomContent.indoorPicUrlFirst,
    }
    console.log('onShareAppMessage', param);
    return param;
  }
})